/**
 * 
 */
package thrust;

import java.awt.*;
import javax.swing.*;
import rtflow.RTflowCode;

/**
 * This is the main class in a simple game that demonstrates the use of code
 * generation from RTflow in a Java application. The Java source code (the three
 * classes Main, GameController and GameView) handles only the user input and
 * graphical output. The actual application logic, including the physics laws
 * and the game artificial intelligence, is all implemented in RTflow. It is
 * accessed from the Java source code through the class RTflowCode, which is
 * generated from RTflow.
 * 
 * The Main class only contains the main() method, which instantiates and
 * initializes the other classes, connects them with each other, opens
 * a window and starts the timer that drives the game.
 */
public class Main {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		} catch (Exception e) {
			// Don't care
		}
		
		// Create and initialize game engine from RTflow code
		RTflowCode rtflowCode = new RTflowCode();
		rtflowCode.initialize();
		rtflowCode.run(); // To ensure all outputs are valid.
		
		// Create and initialize game view
		GameView view = new GameView(rtflowCode);
		view.setSize(640, 480);
		view.setPreferredSize(new Dimension(640, 480));
		
		// Create and show window
		JFrame frame = new JFrame("Thrust");
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.add(view);
		frame.pack();
		frame.setVisible(true);
		
		// Create controller and direct key events to it
		GameController controller = new GameController(view, rtflowCode);
		frame.addKeyListener(controller);
		
		// Create and start timer; direct timer events to controller
		Timer timer = new Timer((int)(rtflowCode.getSampleTime() * 1000), controller);
		timer.start();
	}
}
